require('dotenv').config()
const { GraphQLServer } = require('graphql-yoga')
const multer = require('multer')
const { resolvers } = require('./src/resolvers')
const { db } = require('./src/db')
const upload = multer({ dest: './static/uploads/' })

const server = new GraphQLServer({
  typeDefs: './schema.graphql',
  resolvers,
  context: req => ({
    ...req,
    db,
    debug: true
  })
})

server.express.post('/upload', upload.single('file'), async (req, res) => {
  const { file } = req
  if (!file) await res.json({ error: 'File not received.' })
  await res.json({ file })
})

server.express.get('/upload', async (req, res) => res.json({ very: 'good' }))

server.start(
  {
    cors: {
      credentials: true,
      origin: process.env.FRONTEND_URL
    }
  },
  server => console.log(`Server is running on http://localhost:${server.port}`)
)
